@@ -12,7 +12,7 @@ from .settings_models import HotspotConnectionSettings, WiFiConnectionSettings
 
 
 def wifi_connection(
-    settings: WiFiConnectionSettings, guid: str = str(uuid.uuid4).upper()
+    settings: WiFiConnectionSettings, guid: str = str(uuid.uuid4()).upper()
 ) -> dbus.Dictionary:
     """Builds wifi connection message for NetworkManager communication."""
     return dbus.Dictionary(
@@ -47,7 +47,7 @@ def wifi_connection(
 
 
 def hotspot_connection(
-    settings: HotspotConnectionSettings, guid: str = str(uuid.uuid4).upper()
+    settings: HotspotConnectionSettings, guid: str = str(uuid.uuid4()).upper()
 ) -> dbus.Dictionary:
     """Builds hotspot connection message for NetworkManager communication."""
     return dbus.Dictionary(
